'''
Sistamapy - Simple statuses Mastodon for Python
Copyright (C) 2020 Vitor Guia

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <https://www.gnu.org/licenses/>.
'''
import json
from urllib.request import Request, urlopen
from urllib.parse import urlencode

class Statuses(object):
    '''
    Mastodon statuses
    See https://docs.joinmastodon.org/methods/statuses
    '''
    def __init__(self, instance, token):
        '''
        Mastodon statuses post
        '''
        self.instance = instance
        self.token = token


    def post(self, data):
        '''
        Mastodon post statuses
        '''
        data = urlencode(data)
        data = data.encode('ascii') # data should be bytes

        req = Request(
            'https://' + self.instance + '/api/v1/statuses',
            data,
            headers={
                'Content-type': 'application/x-www-form-urlencoded',
                'Authorization': 'Bearer ' + self.token
            },
            method='POST'
        )
        with urlopen(req) as res:
            res = res.read()

        return json.loads(res)


    def get(self, s_id):
        '''
        Mastodon get statuses
        '''
        req = Request(
            'https://' + self.instance + '/api/v1/statuses/' + str(s_id),
            headers={
                'Authorization': 'Bearer ' + self.token
            },
            method='GET'
        )
        with urlopen(req) as res:
            res = res.read()

        return json.loads(res)


    def delete(self, s_id):
        '''
        Mastodon delete statuses
        '''
        req = Request(
            'https://' + self.instance + '/api/v1/statuses/' + str(s_id),
            headers={
                'Authorization': 'Bearer ' + self.token
            },
            method='DELETE'
        )
        with urlopen(req) as res:
            res = res.read()

        return json.loads(res)



"""
Sistamapy - Simple statuses Mastodon for Python
Copyright (C) 2020 Vitor Guia

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <https://www.gnu.org/licenses/>.
"""

import unittest
from time import time
from os import environ
from sepbit.sistamapy.statuses import Statuses

class StatusesTest(unittest.TestCase):
    """
    Test statuses.py module
    """
    toot_id = 0

    def setUp(self):
        '''
        Set credentials
        '''
        self.toot = Statuses(
            environ['INSTANCE'],
            environ['TOKEN']
        )


    def test_01_post(self):
        """
        Test post method
        """
        post = self.toot.post({
            'status': 'test ' + str(time()),
            'language': 'por',
            'visibility': 'public'
        })

        self.__class__.toot_id = post['id']
        self.assertTrue(post)


    def test_02_get(self):
        """
        Test get method
        """
        get = self.toot.get(
            self.__class__.toot_id
        )

        self.assertTrue(get)


    def test_03_delete(self):
        """
        Test delete method
        """
        delete = self.toot.delete(
            self.__class__.toot_id
        )

        self.assertTrue(delete)


if __name__ == '__main__':
    unittest.main()



#!/usr/bin/env python3
# -*- coding: utf-8 -*-
'''
Sistamapy - Simple statuses Mastodon for Python
Copyright (C) 2020 Vitor Guia

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <https://www.gnu.org/licenses/>.
'''

from setuptools import setup

with open('README.md', 'r') as f:
    README = f.read()

setup(
    name='sepbit.sistamapy',
    version='1.0.1',
    long_description_content_type='text/markdown',
    description='Simple statuses Mastodon for Python',
    long_description=README,
    license='GPL-3.0-or-later',
    keywords='Statuses Mastodon Python',
    author='Vitor Guia',
    maintainer='Sepbit',
    maintainer_email='contato@sepbit.com',
    author_email='contato@vitor.guia.nom.br',
    url='https://gitlab.com/sepbit/sistamapy',
    packages=['sepbit.sistamapy'],
    python_requires='~=3.9',
    install_requires=['setuptools'],
    extras_require={
        'dev': ['check-manifest'],
        'test': ['coverage'],
    },
    test_suite='test',
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: GNU General Public License v3 or later (GPLv3+)',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: Implementation :: CPython',
        'Programming Language :: Python :: Implementation :: PyPy'
    ],
    zip_safe=False,
)
